@@ -1,6 +1,7 @@
 import json
 import logging
-from datetime import datetime
+from dataclasses import asdict
+from datetime import datetime, time
 from functools import wraps
 from uuid import UUID
 
@@ -22,11 +23,11 @@ api_service = ApiService()
 
 class JsonEncoder(DjangoJSONEncoder):
     def default(self, o):
-        if isinstance(o, datetime):
+        if isinstance(o, datetime | time):
             return o.isoformat()
         if isinstance(o, UUID):
             return str(o)
-        if isinstance(o, ImageFieldFile) or isinstance(o, FieldFile):
+        if isinstance(o, ImageFieldFile | FieldFile):
             try:
                 return o.url
             except ValueError:
@@ -149,7 +150,7 @@ async def dashboard_widget(request: HttpRequest, model: str) -> JsonResponse:
 
 
 @csrf_exempt
-async def list(request: HttpRequest, model: str) -> JsonResponse:
+async def list_objs(request: HttpRequest, model: str) -> JsonResponse:
     """This method is used to get a list of objects.
 
     :params request: a request object.
@@ -162,12 +163,13 @@ async def list(request: HttpRequest, model: str) -> JsonResponse:
     """
     if request.method != "GET":
         return JsonResponse({"error": "Method not allowed"}, status=405)
-    filters = request.GET.dict()
-    search = filters.get("search", None)
-    sort_by = filters.get("sort_by", None)
-    offset = filters.get("offset", 0)
-    limit = filters.get("limit", 10)
     try:
+        filters = request.GET.dict()
+        search = filters.get("search", None)
+        sort_by = filters.get("sort_by", None)
+        offset = int(filters.get("offset", 0))
+        limit = int(filters.get("limit", 10))
+
         objs, total = await api_service.list(
             request.COOKIES.get(settings.ADMIN_SESSION_ID_KEY, None),
             model,
@@ -183,6 +185,8 @@ async def list(request: HttpRequest, model: str) -> JsonResponse:
                 "results": objs,
             }
         )
+    except ValueError:
+        return JsonResponse({"detail": "Invalid format of get parameters"}, status=422)
     except AdminApiException as e:
         return JsonResponse({"detail": e.detail}, status=e.status_code)
 
@@ -386,4 +390,4 @@ async def configuration(request: HttpRequest) -> JsonResponse:
     obj = await api_service.get_configuration(
         request.COOKIES.get(settings.ADMIN_SESSION_ID_KEY, None),
     )
-    return JsonResponse(obj.dict())
+    return JsonResponse(asdict(obj))
