@@ -1,4 +1,5 @@
 import logging
+from dataclasses import asdict
 from uuid import UUID
 
 from flask import Blueprint, Response, make_response, request
@@ -36,7 +37,7 @@ async def sign_in() -> Response:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/sign-out", methods=["POST"])
@@ -56,7 +57,7 @@ async def sign_out() -> Response:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/me", methods=["GET"])
@@ -78,10 +79,10 @@ async def me() -> dict:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
-@api_router.route("/dashboard-widge/<string:model>", methods=["GET"])
+@api_router.route("/dashboard-widget/<string:model>", methods=["GET"])
 async def dashboard_widget(model: str) -> dict:
     """This method is used to get a dashboard widget data.
 
@@ -108,11 +109,11 @@ async def dashboard_widget(model: str) -> dict:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/list/<string:model>", methods=["GET"])
-async def list(model: str) -> dict:
+async def list_objs(model: str) -> dict:
     """This method is used to get a list of objects.
 
     :params request: a request object.
@@ -123,12 +124,12 @@ async def list(model: str) -> dict:
     :params limit: a limit.
     :return: A list of objects.
     """
-    filters = request.args.to_dict()
-    search = filters.get("search", None)
-    sort_by = filters.get("sort_by", None)
-    offset = int(filters.get("offset", 0))
-    limit = int(filters.get("limit", 10))
     try:
+        filters = request.args.to_dict()
+        search = filters.get("search", None)
+        sort_by = filters.get("sort_by", None)
+        offset = int(filters.get("offset", 0))
+        limit = int(filters.get("limit", 10))
         objs, total = await api_service.list(
             request.cookies.get(settings.ADMIN_SESSION_ID_KEY, None),
             model,
@@ -142,10 +143,14 @@ async def list(model: str) -> dict:
             "total": total,
             "results": objs,
         }
+    except ValueError as e:
+        http_exception = HTTPException("Invalid format of get parameters")
+        http_exception.code = 422
+        raise http_exception from e
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/retrieve/<string:model>/<string:id>", methods=["GET"])
@@ -169,7 +174,7 @@ async def get(model: str, id: UUID | int) -> dict:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/add/<string:model>", methods=["POST"])
@@ -190,10 +195,10 @@ async def add(model: str) -> dict:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
-@api_router.route("/change-password/<string:id>", methods=["PATCH"])  # type: ignore
+@api_router.route("/change-password/<string:id>", methods=["PATCH"])  # type: ignore [type-var]
 async def change_password(id: UUID | int) -> UUID | int:
     """This method is used to change password.
 
@@ -216,7 +221,7 @@ async def change_password(id: UUID | int) -> UUID | int:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/change/<string:model>/<string:id>", methods=["PATCH"])
@@ -243,7 +248,7 @@ async def change(model: str, id: UUID | int) -> dict:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/export/<string:model>", methods=["POST"])
@@ -277,10 +282,10 @@ async def export(model: str) -> Response:
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
-@api_router.route("/delete/<string:model>/<string:id>", methods=["DELETE"])  # type: ignore
+@api_router.route("/delete/<string:model>/<string:id>", methods=["DELETE"])  # type: ignore [type-var]
 async def delete(
     model: str,
     id: UUID | int,
@@ -304,10 +309,10 @@ async def delete(
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
-@api_router.route("/action/<string:model>/<string:action>", methods=["POST"])  # type: ignore
+@api_router.route("/action/<string:model>/<string:action>", methods=["POST"])
 async def action(
     model: str,
     action: str,
@@ -332,7 +337,7 @@ async def action(
     except AdminApiException as e:
         http_exception = HTTPException(e.detail)
         http_exception.code = e.status_code
-        raise http_exception
+        raise http_exception from e
 
 
 @api_router.route("/configuration", methods=["GET"])
@@ -345,4 +350,4 @@ async def configuration() -> dict:
     obj = await api_service.get_configuration(
         request.cookies.get(settings.ADMIN_SESSION_ID_KEY, None),
     )
-    return obj.dict()
+    return asdict(obj)
