@@ -1,6 +1,5 @@
 import logging
-import os
-from datetime import date
+from datetime import date, time
 
 from flask import Blueprint
 from flask.json.provider import DefaultJSONProvider
@@ -15,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 class JSONProvider(DefaultJSONProvider):
     def default(self, o):
-        if isinstance(o, date):
+        if isinstance(o, date | time):
             return o.isoformat()
         return super().default(o)
 
@@ -25,8 +24,7 @@ app = Blueprint(
     __name__,
     url_prefix="/parent",
     static_url_path="/static",
-    static_folder=os.path.join(ROOT_DIR, "static"),
-    template_folder=os.path.join(ROOT_DIR, "templates"),
+    static_folder=ROOT_DIR / "static",
 )
 app.register_blueprint(views_router)
 app.register_blueprint(api_router)
