@@ -1,5 +1,6 @@
 import base64
 import binascii
+from pathlib import Path
 from uuid import UUID
 
 from fastadmin.models.schemas import ModelFieldWidgetSchema
@@ -11,13 +12,15 @@ def sanitize_filter_value(value: str) -> bool | None | str:
     :params value: a value.
     :return: A sanitized value.
     """
-    if value == "false":
-        return False
-    elif value == "true":
-        return True
-    elif value == "null":
-        return None
-    return value
+    match value:
+        case "false":
+            return False
+        case "true":
+            return True
+        case "null":
+            return None
+        case _:
+            return value
 
 
 def sanitize_filter_key(key: str, fields: list[ModelFieldWidgetSchema]) -> tuple[str, str]:
@@ -28,12 +31,11 @@ def sanitize_filter_key(key: str, fields: list[ModelFieldWidgetSchema]) -> tuple
     :return: A tuple of sanitized key and condition.
     """
     if "__" not in key:
-        key = f"{key}__exact"
-    field_name = key.split("__", 1)[0]
-    condition = key.split("__", 1)[1]
+        key += "__exact"
+    field_name, _, condition = key.partition("__")
     field: ModelFieldWidgetSchema | None = next((field for field in fields if field.name == field_name), None)
     if field and field.filter_widget_props.get("parentModel") and not field.is_m2m:
-        field_name = f"{field_name}_id"
+        field_name += "_id"
     return field_name, condition
 
 
@@ -50,32 +52,26 @@ def is_valid_uuid(uuid_to_test: str) -> bool:
     return str(uuid_obj) == uuid_to_test
 
 
-def is_digit(digit_to_test: str) -> bool:
-    """Check if digit_to_test is a digit.
-
-    :param digit_to_test: A digit to test.
-    :return: True if digit_to_test is a digit, False otherwise.
-    """
-    try:
-        int(digit_to_test)
-    except ValueError:
-        return False
-    return True
-
-
 def is_valid_id(id: UUID | int) -> bool:
     """Check if id is a valid id.
 
     :param id: An id to test.
     :return: True if id is a valid id, False otherwise.
     """
-    return is_digit(str(id)) or is_valid_uuid(str(id))
+    if is_valid_uuid(str(id)):
+        return True
+    try:
+        int(id)
+        return True
+    except ValueError:
+        pass
+    return False
 
 
 def is_valid_base64(value: str) -> bool:
-    """Check if s is a valid base64.
+    """Check if a string is a valid base64.
 
-    :param s: A string to test.
+    :param value: A string to test.
     :return: True if s is a valid base64, False otherwise.
     """
     try:
@@ -83,3 +79,11 @@ def is_valid_base64(value: str) -> bool:
         return True
     except binascii.Error:
         return False
+
+
+def get_template(template: Path, context: dict) -> str:
+    with Path.open(template, "r") as file:
+        content = file.read()
+        for key, value in context.items():
+            content = content.replace(f"{{{{{key}}}}}", value)
+        return content
