@@ -1,6 +1,8 @@
 import inspect
+import logging
+import re
 from collections.abc import Sequence
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from io import BytesIO, StringIO
 from typing import Any, cast
 from uuid import UUID
@@ -31,6 +33,29 @@ from fastadmin.models.helpers import (
 from fastadmin.models.schemas import ConfigurationSchema, ModelSchema
 from fastadmin.settings import settings
 
+logger = logging.getLogger(__name__)
+
+
+def convert_id(id: str | int | UUID) -> int | UUID | None:
+    """Convert the given id to int or UUID.
+
+    :param id: A string value.
+    :return: An int or UUID value. Or None if the given id is invalid.
+    """
+    if isinstance(id, int | UUID):
+        return id
+
+    # Check if the input_str is an integer
+    if re.fullmatch(r"\d+", id):
+        return int(id)
+
+    # Check if the input_str is a valid UUID
+    if re.fullmatch(r"[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}", id):
+        return UUID(id)
+
+    logger.warning("Invalid id: %s", id)
+    return None
+
 
 async def get_user_id_from_session_id(session_id: str | None) -> UUID | int | None:
     """This method is used to get user id from session_id.
@@ -54,11 +79,14 @@ async def get_user_id_from_session_id(session_id: str | None) -> UUID | int | No
     if not session_expired_at:
         return None
 
-    if datetime.fromisoformat(session_expired_at) < datetime.utcnow():
+    if datetime.fromisoformat(session_expired_at).replace(tzinfo=timezone.utc) < datetime.now(timezone.utc):
         return None
 
     user_id = token_payload.get("user_id")
+    if not user_id:
+        return None
 
+    user_id = convert_id(user_id)
     if not user_id or not await admin_model.get_obj(user_id):
         return None
 
@@ -73,24 +101,27 @@ class ApiService:
     ) -> str:
         model = settings.ADMIN_USER_MODEL
         admin_model = get_admin_model(model)
+
         if not admin_model:
             raise AdminApiException(401, detail=f"{model} model is not registered.")
 
         if inspect.iscoroutinefunction(admin_model.authenticate):
             authenticate_fn = admin_model.authenticate
         else:
-            authenticate_fn = sync_to_async(admin_model.authenticate)
+            authenticate_fn = sync_to_async(admin_model.authenticate)  # type: ignore [arg-type]
 
         user_id = await authenticate_fn(payload.username, payload.password)
 
-        if not user_id or not (isinstance(user_id, int) or isinstance(user_id, UUID)):
+        if not user_id or not isinstance(user_id, int | UUID):
             raise AdminApiException(401, detail="Invalid credentials.")
 
-        now = datetime.utcnow()
+        now = datetime.now(timezone.utc)
         session_expired_at = now + timedelta(seconds=settings.ADMIN_SESSION_EXPIRED_AT)
+        if isinstance(user_id, UUID):
+            user_id = str(user_id)
         return jwt.encode(
             {
-                "user_id": str(user_id),
+                "user_id": user_id,
                 "session_expired_at": session_expired_at.isoformat(),
             },
             settings.ADMIN_SECRET_KEY,
@@ -129,11 +160,16 @@ class ApiService:
         if not dashboard_widget_model:
             raise AdminApiException(404, detail=f"{model} model is not registered.")
 
-        data = await dashboard_widget_model.get_data(
+        if inspect.iscoroutinefunction(dashboard_widget_model.get_data):
+            get_data = dashboard_widget_model.get_data
+        else:
+            get_data = sync_to_async(dashboard_widget_model.get_data)  # type: ignore [arg-type]
+        data = await get_data(
             min_x_field=query_params.min_x_field,
             max_x_field=query_params.max_x_field,
             period_x_field=query_params.period_x_field,
         )
+
         DashboardWidgetDataOutputSchema(**data)
         return data
 
@@ -143,7 +179,7 @@ class ApiService:
         model: str,
         search: str | None = None,
         sort_by: str | None = None,
-        filters: dict = {},
+        filters: dict | None = None,
         offset: int | None = 0,
         limit: int | None = 10,
     ) -> tuple[list[dict], int]:
@@ -154,7 +190,7 @@ class ApiService:
         query_params = ListQuerySchema(
             search=search,
             sort_by=sort_by,
-            filters=filters,
+            filters=filters or {},
             offset=offset,
             limit=limit,
         )
@@ -174,7 +210,7 @@ class ApiService:
         exclude_filter_fields = ("search", "sort_by", "offset", "limit")
         query_filters: dict[tuple[str, str], bool | str | None] | None = None
         if query_params.filters:
-            for k in query_params.filters.keys():
+            for k in query_params.filters:
                 if k in exclude_filter_fields:
                     continue
                 field = k.split("__", 1)[0]
@@ -239,7 +275,7 @@ class ApiService:
         admin_model = get_admin_or_admin_inline_model(model)
         if not admin_model:
             raise AdminApiException(404, detail=f"{model} model is not registered.")
-        return await admin_model.save_model(None, payload)  # type: ignore
+        return await admin_model.save_model(None, payload)  # type: ignore [return-value]
 
     async def change_password(
         self,
@@ -256,6 +292,8 @@ class ApiService:
             raise AdminApiException(404, detail=f"{settings.ADMIN_USER_MODEL} model is not registered.")
 
         payload = ChangePasswordInputSchema(**payload)
+        if payload.password != payload.confirm_password:
+            raise AdminApiException(422, detail="Passwords do not match")
 
         if not hasattr(admin_model, "change_password"):
             raise AdminApiException(
@@ -265,7 +303,7 @@ class ApiService:
         if inspect.iscoroutinefunction(admin_model.change_password):
             change_password_fn = admin_model.change_password
         else:
-            change_password_fn = sync_to_async(admin_model.change_password)
+            change_password_fn = sync_to_async(admin_model.change_password)  # type: ignore [arg-type]
         await change_password_fn(id, payload.password)
 
     async def change(
@@ -295,7 +333,7 @@ class ApiService:
         payload: ExportInputSchema,
         search: str | None = None,
         sort_by: str | None = None,
-        filters: dict = {},
+        filters: dict | None = None,
     ) -> tuple[str, str, StringIO | BytesIO | None]:
         current_user_id = await get_user_id_from_session_id(session_id)
         if not current_user_id:
@@ -304,7 +342,7 @@ class ApiService:
         query_params = ListQuerySchema(
             search=search,
             sort_by=sort_by,
-            filters=filters,
+            filters=filters or {},
             offset=payload.offset,
             limit=payload.limit,
         )
@@ -324,7 +362,7 @@ class ApiService:
         exclude_filter_fields = ("search", "sort_by", "offset", "limit")
         query_filters: dict[tuple[str, str], bool | str | None] | None = None
         if query_params.filters:
-            for k in query_params.filters.keys():
+            for k in query_params.filters:
                 if k in exclude_filter_fields:
                     continue
                 field = k.split("__", 1)[0]
@@ -422,12 +460,13 @@ class ApiService:
                 username_field=settings.ADMIN_USER_MODEL_USERNAME_FIELD,
                 date_format=settings.ADMIN_DATE_FORMAT,
                 datetime_format=settings.ADMIN_DATETIME_FORMAT,
+                disable_crop_image=settings.ADMIN_DISABLE_CROP_IMAGE,
                 models=[],
                 dashboard_widgets=[],
             )
 
         admin_models = cast(dict[Any, ModelAdmin | InlineModelAdmin], get_admin_models())
-        models = cast(Sequence[ModelSchema], generate_models_schema(admin_models, user_id=current_user_id))
+        models = cast(Sequence[ModelSchema], await generate_models_schema(admin_models, user_id=current_user_id))
         dashboard_widgets = generate_dashboard_widgets_schema()
         return ConfigurationSchema(
             site_name=settings.ADMIN_SITE_NAME,
@@ -438,6 +477,7 @@ class ApiService:
             username_field=settings.ADMIN_USER_MODEL_USERNAME_FIELD,
             date_format=settings.ADMIN_DATE_FORMAT,
             datetime_format=settings.ADMIN_DATETIME_FORMAT,
+            disable_crop_image=settings.ADMIN_DISABLE_CROP_IMAGE,
             models=models,
             dashboard_widgets=dashboard_widgets,
-        )
+        )  # type: ignore [call-arg]
