@@ -3,7 +3,7 @@ from typing import Any
 from uuid import UUID
 
 from asgiref.sync import sync_to_async
-from pony.orm import commit, db_session, delete, desc, flush, select
+from pony.orm import commit, db_session, desc, flush
 
 from fastadmin.models.base import InlineModelAdmin, ModelAdmin
 from fastadmin.models.schemas import ModelFieldWidgetSchema, WidgetType
@@ -233,8 +233,7 @@ class PonyORMMixin:
         :return: A tuple of list of objects and total count.
         """
 
-        qs = select(m for m in self.model_cls)
-
+        qs = getattr(self.model_cls, "select")(lambda m: m)  # noqa: B009
         if filters:
             for field_with_condition, value in filters.items():
                 field = field_with_condition[0]
@@ -257,14 +256,17 @@ class PonyORMMixin:
                     case "contains":
                         pony_condition = "in"
                     case "icontains":
+                        # TODO: support icontains here
                         pony_condition = "in"
                 filter_expr = f""""{value}" {pony_condition}  m.{field}"""
                 qs = qs.filter(filter_expr)
 
         if search and self.search_fields:
             ids = []
-            for f in self.search_fields:
-                qs_ids = qs.filter(lambda m: search.lower() in getattr(m, f).lower())
+            for search_field in self.search_fields:
+                # TODO: support icontains here
+                filter_expr = f""""{search}" in m.{search_field}"""
+                qs_ids = qs.filter(filter_expr)
                 ids += [o.id for o in qs_ids]
             qs = qs.filter(lambda m: m.id in set(ids))
 
@@ -326,7 +328,10 @@ class PonyORMMixin:
         :params id: an id of object.
         :return: None.
         """
-        delete(o for o in self.model_cls if getattr(o, self.get_model_pk_name(self.model_cls)) == id)
+        obj = next((i for i in self.model_cls.select(**{self.get_model_pk_name(self.model_cls): id})), None)
+        if not obj:
+            return
+        obj.delete()
         flush()
         commit()
 
@@ -362,12 +367,13 @@ class PonyORMMixin:
         key_id = self.get_model_pk_name(self.model_cls)
         obj = next((i for i in self.model_cls.select(**{key_id: getattr(obj, key_id)})), None)
         if not obj:
-            return None
-        rel_model_cls = getattr(self.model_cls, field).py_type
-        rel_key_id = self.get_model_pk_name(rel_model_cls)
-        rel_objs = list(rel_model_cls.select(lambda o: getattr(o, rel_key_id) in ids))
-        obj.participants.clear()
-        obj.participants.add(rel_objs)
+            return
+        getattr(obj, field).clear()
+        if ids:
+            rel_model_cls = getattr(self.model_cls, field).py_type
+            rel_key_id = self.get_model_pk_name(rel_model_cls)
+            rel_objs = list(rel_model_cls.select(lambda o: getattr(o, rel_key_id) in ids))
+            getattr(obj, field).add(rel_objs)
         flush()
         commit()
 
@@ -382,7 +388,7 @@ class PonyORMMixin:
 
         :return: A list of ids.
         """
-        pass
+        ...
 
     @sync_to_async
     @db_session
