@@ -1,7 +1,8 @@
+import contextlib
 from typing import Any
 from uuid import UUID
 
-from sqlalchemy import and_, func, inspect, or_, select, text
+from sqlalchemy import BIGINT, Integer, and_, func, inspect, or_, select, text
 from sqlalchemy.orm import selectinload
 
 from fastadmin.models.base import InlineModelAdmin, ModelAdmin
@@ -31,7 +32,7 @@ class SqlAlchemyMixin:
         :return: A list of ModelFieldWidgetSchema.
         """
         mapper = inspect(self.model_cls)
-        orm_model_fields = [f for f in mapper.c if not f.foreign_keys] + [f for f in mapper.relationships]
+        orm_model_fields = [f for f in mapper.c if not f.foreign_keys] + list(mapper.relationships)
 
         fields = []
         for orm_model_field in orm_model_fields:
@@ -261,21 +262,27 @@ class SqlAlchemyMixin:
                 for field_with_condition, value in filters.items():
                     field = field_with_condition[0]
                     condition = field_with_condition[1]
+                    model_field = getattr(self.model_cls, field)
+
+                    if isinstance(model_field.expression.type, BIGINT | Integer):
+                        with contextlib.suppress(ValueError, TypeError):
+                            value = int(value)
+
                     match condition:
                         case "lte":
-                            q.append(getattr(self.model_cls, field) >= value)
+                            q.append(model_field >= value)
                         case "gte":
-                            q.append(getattr(self.model_cls, field) <= value)
+                            q.append(model_field <= value)
                         case "lt":
-                            q.append(getattr(self.model_cls, field) > value)
+                            q.append(model_field > value)
                         case "gt":
-                            q.append(getattr(self.model_cls, field) < value)
+                            q.append(model_field < value)
                         case "exact":
-                            q.append(getattr(self.model_cls, field) == value)
+                            q.append(model_field == value)
                         case "contains":
-                            q.append(getattr(self.model_cls, field).like(f"%{value}%"))
+                            q.append(model_field.like(f"%{value}%"))
                         case "icontains":
-                            q.append(getattr(self.model_cls, field).ilike(f"%{value}%"))
+                            q.append(model_field.ilike(f"%{value}%"))
                 qs = qs.filter(and_(*q))
 
             if search and self.search_fields:
@@ -290,7 +297,7 @@ class SqlAlchemyMixin:
                 sort_by_text = ", ".join([convert_sort_by(f) for f in self.ordering])
                 qs = qs.order_by(text(sort_by_text))
 
-            objs = await session.execute(select(func.count()).select_from(qs))  # type: ignore
+            objs = await session.execute(select(func.count()).select_from(qs))  # type: ignore [arg-type]
             total = objs.scalar()
 
             if self.list_select_related:
@@ -313,6 +320,13 @@ class SqlAlchemyMixin:
         async with sessionmaker() as session:
             return await session.get(self.model_cls, id)
 
+    def _get_foreign_key_fields(self) -> list[str]:
+        """Returns a list of foreign key fields for the model.
+
+        :return: List of foreign key field names.
+        """
+        return [column.name for column in self.model_cls.__table__.columns if column.foreign_keys]
+
     async def orm_save_obj(self, id: UUID | Any | None, payload: dict) -> Any:
         """This method is used to save orm/db model object.
 
@@ -320,6 +334,12 @@ class SqlAlchemyMixin:
         :params payload: a dict of payload.
         :return: An object.
         """
+        for fk_field_name in self._get_foreign_key_fields():
+            if fk_field_name in payload and isinstance(payload[fk_field_name], str):
+                with contextlib.suppress(ValueError, TypeError):
+                    # convert string to int for foreign key fields for postgresql alchemy
+                    payload[fk_field_name] = int(payload[fk_field_name])
+
         sessionmaker = self.get_sessionmaker()
         async with sessionmaker() as session:
             if id:
@@ -346,6 +366,7 @@ class SqlAlchemyMixin:
         async with sessionmaker() as session:
             obj = await session.get(self.model_cls, id)
             await session.delete(obj)
+            await session.commit()
 
     async def orm_get_m2m_ids(self, obj: Any, field: str) -> list[int | UUID]:
         """This method is used to get m2m ids.
@@ -392,14 +413,19 @@ class SqlAlchemyMixin:
                 getattrs(orm_model_field.secondary, f"c.{obj_field_name}") == obj_id
             )
             await session.execute(qs)
-            for id in ids:
+            for rel_id in ids:
+                with contextlib.suppress(ValueError, TypeError):
+                    rel_id = int(rel_id)
+                with contextlib.suppress(ValueError, TypeError):
+                    obj_id = int(obj_id)
                 values.append(
                     {
-                        rel_field_name: id,
+                        rel_field_name: rel_id,
                         obj_field_name: obj_id,
                     }
                 )
-            await session.execute(orm_model_field.secondary.insert().values(values))
+            if values:
+                await session.execute(orm_model_field.secondary.insert().values(values))
             await session.commit()
 
     async def orm_save_upload_field(self, obj: Any, field: str, base64: str) -> None:
@@ -411,7 +437,7 @@ class SqlAlchemyMixin:
 
         :return: A list of ids.
         """
-        pass
+        ...
 
 
 class SqlAlchemyModelAdmin(SqlAlchemyMixin, ModelAdmin):
