@@ -1,6 +1,10 @@
+import functools
+import operator
 from typing import Any
 from uuid import UUID
 
+from tortoise.expressions import Q
+
 from fastadmin.models.base import InlineModelAdmin, ModelAdmin
 from fastadmin.models.schemas import ModelFieldWidgetSchema, WidgetType
 from fastadmin.settings import settings
@@ -58,7 +62,7 @@ class TortoiseMixin:
             if with_upload is not None and with_upload and not is_upload:
                 continue
 
-            is_pk = getattr(orm_model_field, "index", False)
+            is_pk = getattr(orm_model_field, "pk", False)
             is_immutable = (
                 is_pk or getattr(orm_model_field, "auto_now", False) or getattr(orm_model_field, "auto_now_add", False)
             ) and field_name not in self.readonly_fields
@@ -244,11 +248,13 @@ class TortoiseMixin:
                 qs = qs.filter(**{f"{field}__{condition}" if condition != "exact" else field: value})
 
         if search and self.search_fields:
-            ids = []
-            for f in self.search_fields:
-                qs = qs.filter(**{f + "__icontains": search})
-                ids += await qs.values_list(self.get_model_pk_name(self.model_cls), flat=True)
-            qs = qs.filter(id__in=set(ids))
+            qs = qs.filter(
+                functools.reduce(
+                    operator.or_,
+                    (Q(**{f + "__icontains": search}) for f in self.search_fields),
+                    Q(),
+                )
+            )
 
         if sort_by:
             qs = qs.order_by(sort_by)
@@ -323,19 +329,18 @@ class TortoiseMixin:
 
         :return: A list of ids.
         """
-        if not ids:
-            return
         m2m_rel = getattr(obj, field)
 
         await m2m_rel.clear()
         remote_model = m2m_rel.remote_model
         remote_model_objs = []
-        for id in ids:
+        for rel_id in ids:
             remote_model_obj = remote_model()
-            setattr(remote_model_obj, self.get_model_pk_name(remote_model), id)
-            setattr(remote_model_obj, "_saved_in_db", True)
+            setattr(remote_model_obj, self.get_model_pk_name(remote_model), rel_id)
+            remote_model_obj._saved_in_db = True
             remote_model_objs.append(remote_model_obj)
-        await m2m_rel.add(*remote_model_objs)
+        if remote_model_objs:
+            await m2m_rel.add(*remote_model_objs)
 
     async def orm_save_upload_field(self, obj: Any, field: str, base64: str) -> None:
         """This method is used to save upload field.
@@ -346,7 +351,7 @@ class TortoiseMixin:
 
         :return: A list of ids.
         """
-        pass
+        ...
 
 
 class TortoiseModelAdmin(TortoiseMixin, ModelAdmin):
